@@ -1,8 +1,10 @@
+from formset.boundfield import ClassList
 from formset.renderers.default import FormRenderer as DefaultFormRenderer
 
 
 class FormRenderer(DefaultFormRenderer):
     max_options_per_line = 4
+    framework = 'bulma'
 
     def __init__(self, **kwargs):
         kwargs.setdefault('label_css_classes', 'label')
@@ -20,7 +22,7 @@ class FormRenderer(DefaultFormRenderer):
     })
 
     def _amend_input(self, context):
-        context['widget']['attrs']['class'] = 'input'
+        context['widget']['attrs']['class'] = ClassList('input')
         return context
 
     def _amend_label(self, context):
@@ -28,13 +30,13 @@ class FormRenderer(DefaultFormRenderer):
 
     def _amend_multiple_input(self, context, css_class):
         context = super()._amend_multiple_input(context)
-        css_classes = [css_class]
+        label_css_classes = ClassList(css_class)
         if not context['widget'].get('inlined_options'):
-            css_classes.append('is-block ml-0 mb-1')
+            label_css_classes.add('is-block ml-0 mb-1')
         for _, optgroup, _ in context['widget']['optgroups']:
             for option in optgroup:
                 option['template_name'] = 'formset/bulma/widgets/input_option.html'
-                option['label_css_classes'] = ' '.join(css_classes)
+                option['label_css_classes'] = label_css_classes
         return context
 
     def _amend_checkbox_select(self, context):
@@ -44,7 +46,7 @@ class FormRenderer(DefaultFormRenderer):
         return self._amend_multiple_input(context, 'radio mr-1')
 
     def _amend_textarea(self, context):
-        context['widget']['attrs']['class'] = 'textarea'
+        context['widget']['attrs']['class'] = ClassList('textarea')
         return context
 
     def _amend_collection(self, context):
@@ -66,4 +68,5 @@ class FormRenderer(DefaultFormRenderer):
         'django/forms/widgets/textarea.html': _amend_textarea,
         'django/forms/widgets/radio.html': _amend_radio,
         'formset/default/collection.html': _amend_collection,
+        'formset/default/widgets/richtextarea.html': _amend_textarea,
     })
