@@ -105,11 +105,7 @@ class HolderMixin:
         return super().is_valid()
 
 
-class FormMixin(HolderMixin):
-    """
-    Mixin class to be added to a native Django Form. This is required to add
-    """
-
+class FormDecoratorMixin:
     def __init__(self, error_class=FormsetErrorList, **kwargs):
         kwargs['error_class'] = error_class
         super().__init__(**kwargs)
@@ -126,8 +122,17 @@ class FormMixin(HolderMixin):
     def form_id(self):
         # The "form" tag is used to link fields to their form owner
         # See https://developer.mozilla.org/en-US/docs/Web/HTML/Element/input#attr-form for details
-        if self.prefix and self.auto_id and '%s' in str(self.auto_id):
-            return self.auto_id % self.prefix
+        auto_id = self.auto_id if '%s' in str(self.auto_id) else 'id_%s'
+        if self.prefix:
+            return auto_id % self.prefix
+        else:
+            return auto_id % self.__class__.__name__.lower()
+
+
+class FormMixin(FormDecoratorMixin, HolderMixin):
+    """
+    Mixin class to be added to a native Django Form. This is required to add
+    """
 
     def add_prefix(self, field_name):
         """
