@@ -1,18 +1,19 @@
 import json
 
+from django.db import transaction
 from django.http.response import HttpResponseBadRequest, JsonResponse
 from django.utils.functional import cached_property
 from django.views.generic.base import ContextMixin, TemplateResponseMixin, View
-from django.views.generic.edit import FormView as GenericFormView
 from django.views.generic.detail import SingleObjectMixin
+from django.views.generic.edit import FormView as GenericFormView
 
 from formset.upload import FileUploadMixin
-from formset.widgets import Selectize, DualSelector
+from formset.widgets import DualSelector, Selectize
 
 
 class IncompleteSelectResponseMixin:
     """
-    Add this mixin class to views classes using forms with incomplete fields. These fields
+    Add this mixin to any Django View class using forms with incomplete fields. These fields
     usually are of type ChoiceField referring to a foreign model and using one of the widgets
     :class:`formset.widgets.Selectize`, :class:`formset.widgets.SelectizeMultiple` or
     :class:`formset.widgets.DualSelector`.
@@ -208,5 +209,6 @@ class EditCollectionView(IncompleteSelectResponseMixin, FileUploadMixin, FormCol
         return initial
 
     def form_collection_valid(self, form_collection):
-        form_collection.construct_instance(self.object, form_collection.cleaned_data)
+        with transaction.atomic():
+            form_collection.construct_instance(self.object, form_collection.cleaned_data)
         return super().form_collection_valid(form_collection)
